@@ -19,6 +19,7 @@ from stardist.models import StarDist3D
 from skimage.filters import gaussian
 from six.moves import reduce
 from matplotlib import cm
+from scipy import spatial
 from skimage.filters import threshold_local, threshold_otsu
 from skimage.segmentation import find_boundaries
 import matplotlib.pyplot as plt
@@ -34,7 +35,7 @@ from scipy.ndimage.filters import gaussian_filter
 from skimage.measure import label
 from csbdeep.utils import normalize
 from skimage import filters
-import tqdm
+from tqdm import tqdm
 from skimage.util import random_noise
 from scipy.ndimage import distance_transform_edt
 from skimage.morphology import skeletonize
@@ -149,7 +150,7 @@ def SimplePrediction(x, UnetModel, StarModel, n_tiles = (2,2), UseProbability =
 
 def crappify_flou_G_P(x, y, mu, sigma, savedirx, savediry, name):
     x = x.astype('float32')
-    gaussiannoise = np.random.normal(mu, sigma*0.05, x.shape)
+    gaussiannoise = np.random.normal(mu, sigma, x.shape)
     x = x + gaussiannoise 
         
     #add noise to original image
